@@ -5,6 +5,7 @@ from collections import defaultdict, Counter
 from xlsxwriter.exceptions import FileCreateError
 from xlsxwriter import Workbook
 from common_utils.os_functions import check_create_new_folder
+from common_utils.sequence_functions import duplicate_elem_add_seq
 from decimal import Decimal
 import datetime 
 import re 
@@ -15,6 +16,8 @@ import numpy as np
 import xlwings as xw 
 import win32com.client as client
 
+from pandas.core.indexes.multi import MultiIndex
+
 """pandas save_excel """
 def pd_save_excel(df,save_path,startrow=0,startcol=0):
 
@@ -207,7 +210,7 @@ def write_multi_tables(xlsxwriter_wb,sheet_name,df_list,direction=0,**kwargs):
 
 
 def df_sheet_check(df_list,sheet_name_list):
-		#防止填入的不是列表格式
+	#防止填入的不是列表格式,防止填入的sheet_name 出现重复
 	if type(df_list) != list:
 		df_list = [df_list]
 	if type(sheet_name_list) != list:
@@ -215,11 +218,14 @@ def df_sheet_check(df_list,sheet_name_list):
 	
 	if len(df_list) != len(sheet_name_list):
 		print('写入的数据表数量和填入的Sheet名称数量不相等,将使用默认Sheet名称')
-		
+
+	sheet_name_list = duplicate_elem_add_seq(sheet_name_list)
+
 	if sheet_name_list == None or sheet_name_list == [ ] :
 		sheet_name_list= []
 		for i in range(len(df_list)):
 			sheet_name_list.append('Sheet {}'.format(i+1))
+
 	return df_list, sheet_name_list
 	
 def write_pct_columns(save_path,df_list,sheet_name_list=[],pct_columns=[],content_columns=[],**kwargs):
@@ -282,14 +288,12 @@ def write_pct_columns(save_path,df_list,sheet_name_list=[],pct_columns=[],conten
 
 	save_xlsxwriter_wb(xlsxwriter_wb,save_path)
 
-
 def replace_invalid_strs(string):
 	invalid_strs = [ '\ud835' ]
 	for i in invalid_strs:
 		string = string.replace(i,'')
 	return string 
 
-
 def refresh_excel_calculations(file_path):
 	if not os.path.isabs(file_path):
 		file_path = os.path.join(os.getcwd(), file_path)
@@ -320,7 +324,6 @@ def refresh_excel_calculations(file_path):
 # 	xlwb.Close(True)
 # 	xlapp.Quit
 
-
 def write_format_columns(save_path,df_list,sheet_name_list=[],pct_columns=[],round_columns=[],content_columns=[],**kwargs):
 	"""给定一个表格，用百分比写入包含指定文字的列,表头wrap_text, 添加选项,上面write_pct_columns方式不写是不希望每列str都变成text格式，
 	   正常应该是常规格式
@@ -354,6 +357,9 @@ def write_format_columns(save_path,df_list,sheet_name_list=[],pct_columns=[],rou
 	for df,sheet_name in zip(df_list,sheet_name_list):
 		xlsxwriter_ws = xlsxwriter_wb.add_worksheet(sheet_name)
 
+		#是否属于MultiIndex,如果是，需要确保写入完整--暂时不添加该功能
+		# if isinstance(df.column, MultiIndex):
+
 		header_columns = list(df.columns)
 
 		if not df.empty:
@@ -371,8 +377,8 @@ def write_format_columns(save_path,df_list,sheet_name_list=[],pct_columns=[],rou
 				elif df[column].apply(type).eq(str).all():
 					column_format = text_format
 				#如果本列是日期类型,采用日期格式写入, 第二步应该到判断content_columns 还是 date? -- 以可以输入的参数为优先做判断
-				elif np.issubdtype(df[column].dtype, np.datetime64) :
-					column_values = []
+				elif np.issubdtype(df[column].dtype, np.datetime64)  :
+					column_values = [ x if x == x else '' for x in column_values]
 					column_format = date_format
 				#是否整列都是float格式
 				# elif df[column].apply(type).eq(float).all():
@@ -570,7 +576,6 @@ def format_table(worksheet,format_style,kwargs):
 	return worksheet 
 
 
-
 def save_xlsxwriter_wb(xlsxwriter_wb,save_path):
 	#检查是否存在save_path路径
 	check_create_new_folder(save_path)
@@ -584,10 +589,17 @@ def save_xlsxwriter_wb(xlsxwriter_wb,save_path):
 	print('{0} Saved'.format(save_path))
 
 
-# write_multi_tables(xlsxwriter_wb,sheet_name,df_list,direction=0,**kwargs):
+def save_csv(df, save_path):
+	check_create_new_folder(save_path)
+	close_tag = 0
+	while close_tag <= 0:
+		try:
+			df.to_csv(save_path,index=False)
+			close_tag += 1 
+		except PermissionError:
+			input('\nFailed to write file!\n  Please Close "{}" Then Press Enter to Continue'.format(save_path))
+	print('{0} Saved'.format(save_path))
 
-# def save_excel_xlsxwriter(df_list,sheet_name_list,direction=0,**kwargs):
-# 	Workbook()
 
 def save_excel(df_list,save_path,sheet_name_list=None,format_style=None,**kwargs):
 	"""
